@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ad-blocker.c,v 1.8 2005/01/28 22:28:56 chpe Exp $
+ *  $Id: ad-blocker.c,v 1.9 2006/01/08 23:05:50 jframeau Exp $
  */
 
 #include "config.h"
@@ -85,23 +85,12 @@ ad_blocker_new (AdUriTester *uri_tester)
 			     NULL);
 }
 
-gboolean
-ad_blocker_test_uri (AdBlocker *blocker,
-		     const char *uri,
-		     AdUriCheckType type)
+void
+ad_blocker_blocked_uri (AdBlocker *blocker)
 {
-	gboolean ret;
-
-	ret = ad_uri_tester_test_uri (blocker->priv->uri_tester, uri, type);
-
-	if (ret == TRUE)
-	{
 		blocker->priv->num_blocked++;
 
 		g_object_notify (G_OBJECT (blocker), "num-blocked");
-	}
-
-	return ret;
 }
 
 void
