@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-css-menu.c,v 1.10 2005/01/13 16:15:49 chpe Exp $
+ *  $Id: ephy-css-menu.c,v 1.13 2005/11/01 11:28:22 chpe Exp $
  */
 
 #include "config.h"
@@ -148,7 +148,7 @@ create_stylesheet_action (EphyCSSMenu *menu,
 			tooltip = g_strdup (_("Render the page using the default style"));
 			break;
 		default:
-			tooltip = g_strdup_printf (_("Render the page using the \"%s\" style"), 
+			tooltip = g_strdup_printf (_("Render the page using the “%s” style"), 
 						   name);
 			break;
 	}
@@ -233,7 +233,7 @@ ephy_css_menu_rebuild (EphyCSSMenu *menu)
 
 	action = gtk_action_group_get_action (p->menu_action_group,
 					      "ECSSMenuAction");
-	g_object_set (G_OBJECT (action), "sensitive", stylesheets != NULL, NULL);
+	gtk_action_set_sensitive (action, stylesheets != NULL);
 	
 	for (l = stylesheets, i = 0; l != NULL; l = l->next, i++)
 	{
@@ -304,7 +304,7 @@ sync_active_tab_cb (EphyWindow *window,
 	ephy_css_menu_rebuild (menu);
 }
 
-static GtkActionEntry entries[] =
+static const GtkActionEntry entries[] =
 {
 	{ "ECSSMenuAction", NULL, N_("St_yle"), NULL,
 	  N_("Select a different style for this page"), NULL }
